@@ -440,6 +440,11 @@ class TestThTh:
 class TestElGr:
     """Test el_GR bank provider"""
 
+    def test_bank(self, faker, num_samples):
+        for _ in range(num_samples):
+            bank = faker.bank()
+            assert bank in ElGrBankProvider.banks
+
     def test_bban(self, faker, num_samples):
         for _ in range(num_samples):
             assert re.fullmatch(r"\d{23}", faker.bban())
@@ -467,17 +472,16 @@ class TestNlBe:
             assert re.fullmatch(r"\d{12}", bban)
             account_number = bban[:-2]
             check_digits = int(bban[-2:])
-            assert (97 - (int(account_number) % 97)) == check_digits or check_digits == 97
+            assert (int(account_number) % 97) == check_digits or check_digits == 97
 
     def test_iban(self, faker, num_samples):
         for _ in range(num_samples):
             iban = faker.iban()
             assert iban[:2] == NlBeBankProvider.country_code
             assert re.fullmatch(r"\d{2}\d{12}", iban[2:])
-            bban = iban[4:]
-            account_number = bban[:-2]
-            check_digits = int(bban[-2:])
-            assert (97 - (int(account_number) % 97)) == check_digits or check_digits == 97
+            rearranged_iban = iban[4:] + iban[:4]
+            numeric_iban = "".join(str(ord(char) - 55) if char.isalpha() else char for char in rearranged_iban)
+            assert int(numeric_iban) % 97 == 1
 
     def test_swift8_use_dataset(self, faker, num_samples):
         for _ in range(num_samples):
@@ -503,3 +507,17 @@ class TestZhCn:
     def test_bank(self, faker, num_samples):
         for _ in range(num_samples):
             assert re.match(r"[\u4e00-\u9fa5]{2,20}", faker.bank())
+
+
+class TestBaseBankProvider:
+    """Test base bank provider"""
+
+    def test_bank_not_implemented_error(self, faker):
+        """Test that bank() raises AttributeError when no banks attribute exists"""
+
+        provider = BankProvider(faker)
+
+        assert not hasattr(provider, "banks")
+
+        with pytest.raises(AttributeError):
+            provider.bank()
